@@ -2,7 +2,8 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2022 Osimis S.A., Belgium
+ * Copyright (C) 2021-2022 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -184,19 +185,17 @@ namespace OrthancPlugins
                               int bundleIndex,
                               const BundleQuota& quota)
   {
-    using namespace Orthanc;
-
     toRemove.clear();
 
     // Make room in the bundle
     while (!quota.IsSatisfied(bundle))
     {
-      SQLite::Statement s(pimpl_->db_, SQLITE_FROM_HERE, "SELECT seq, fileUuid, fileSize FROM Cache WHERE bundle=? ORDER BY seq");
+      Orthanc::SQLite::Statement s(pimpl_->db_, SQLITE_FROM_HERE, "SELECT seq, fileUuid, fileSize FROM Cache WHERE bundle=? ORDER BY seq");
       s.BindInt(0, bundleIndex);
 
       if (s.Step())
       {
-        SQLite::Statement t(pimpl_->db_, SQLITE_FROM_HERE, "DELETE FROM Cache WHERE seq=?");
+        Orthanc::SQLite::Statement t(pimpl_->db_, SQLITE_FROM_HERE, "DELETE FROM Cache WHERE seq=?");
         t.BindInt64(0, s.ColumnInt64(0));
         t.Run();
 
@@ -216,10 +215,8 @@ namespace OrthancPlugins
   void CacheManager::EnsureQuota(int bundleIndex,
                                  const BundleQuota& quota)
   {
-    using namespace Orthanc;
-
     // Remove the cached files that exceed the quota
-    std::unique_ptr<SQLite::Transaction> transaction(new SQLite::Transaction(pimpl_->db_));
+    std::unique_ptr<Orthanc::SQLite::Transaction> transaction(new Orthanc::SQLite::Transaction(pimpl_->db_));
     transaction->Begin();
 
     Bundle bundle = GetBundle(bundleIndex);
@@ -241,11 +238,9 @@ namespace OrthancPlugins
 
   void CacheManager::ReadBundleStatistics()
   {
-    using namespace Orthanc;
-
     pimpl_->bundles_.clear();
 
-    SQLite::Statement s(pimpl_->db_, SQLITE_FROM_HERE, "SELECT bundle,COUNT(*),SUM(fileSize) FROM Cache GROUP BY bundle");
+    Orthanc::SQLite::Statement s(pimpl_->db_, SQLITE_FROM_HERE, "SELECT bundle,COUNT(*),SUM(fileSize) FROM Cache GROUP BY bundle");
     while (s.Step())
     {
       int index = s.ColumnInt(0);
@@ -264,9 +259,7 @@ namespace OrthancPlugins
       return;
     }
 
-    using namespace Orthanc;
-
-    SQLite::Statement s(pimpl_->db_, SQLITE_FROM_HERE, "SELECT bundle,COUNT(*),SUM(fileSize) FROM Cache GROUP BY bundle");
+    Orthanc::SQLite::Statement s(pimpl_->db_, SQLITE_FROM_HERE, "SELECT bundle,COUNT(*),SUM(fileSize) FROM Cache GROUP BY bundle");
     while (s.Step())
     {
       const Bundle& bundle = GetBundle(s.ColumnInt(0));
@@ -342,9 +335,7 @@ namespace OrthancPlugins
       return;
     }
 
-    using namespace Orthanc;
-
-    std::unique_ptr<SQLite::Transaction> transaction(new SQLite::Transaction(pimpl_->db_));
+    std::unique_ptr<Orthanc::SQLite::Transaction> transaction(new Orthanc::SQLite::Transaction(pimpl_->db_));
     transaction->Begin();
 
     Bundle bundle = GetBundle(bundleIndex);
@@ -355,19 +346,19 @@ namespace OrthancPlugins
 
     // Store the cached content on the disk
     const char* data = content.size() ? &content[0] : NULL;
-    std::string uuid = Toolbox::GenerateUuid();
+    std::string uuid = Orthanc::Toolbox::GenerateUuid();
     pimpl_->storage_.Create(uuid, data, content.size(), Orthanc::FileContentType_Unknown);
 
     // Remove the previous cached value. This might happen if the same
     // item is accessed very quickly twice: Another factory could have
     // been cached a value before the check for existence in Access().
     {
-      SQLite::Statement s(pimpl_->db_, SQLITE_FROM_HERE, "SELECT seq, fileUuid, fileSize FROM Cache WHERE bundle=? AND item=?");
+      Orthanc::SQLite::Statement s(pimpl_->db_, SQLITE_FROM_HERE, "SELECT seq, fileUuid, fileSize FROM Cache WHERE bundle=? AND item=?");
       s.BindInt(0, bundleIndex);
       s.BindString(1, item);
       if (s.Step())
       {
-        SQLite::Statement t(pimpl_->db_, SQLITE_FROM_HERE, "DELETE FROM Cache WHERE seq=?");
+        Orthanc::SQLite::Statement t(pimpl_->db_, SQLITE_FROM_HERE, "DELETE FROM Cache WHERE seq=?");
         t.BindInt64(0, s.ColumnInt64(0));
         t.Run();
 
@@ -377,7 +368,7 @@ namespace OrthancPlugins
     }
 
     {
-      SQLite::Statement s(pimpl_->db_, SQLITE_FROM_HERE, "INSERT INTO Cache VALUES(NULL, ?, ?, ?, ?)");
+      Orthanc::SQLite::Statement s(pimpl_->db_, SQLITE_FROM_HERE, "INSERT INTO Cache VALUES(NULL, ?, ?, ?, ?)");
       s.BindInt(0, bundleIndex);
       s.BindString(1, item);
       s.BindString(2, uuid);
@@ -412,13 +403,12 @@ namespace OrthancPlugins
                                    int bundle,
                                    const std::string& item)
   {
-    using namespace Orthanc;
     SanityCheck();
 
-    std::unique_ptr<SQLite::Transaction> transaction(new SQLite::Transaction(pimpl_->db_));
+    std::unique_ptr<Orthanc::SQLite::Transaction> transaction(new Orthanc::SQLite::Transaction(pimpl_->db_));
     transaction->Begin();
 
-    SQLite::Statement s(pimpl_->db_, SQLITE_FROM_HERE, "SELECT seq, fileUuid, fileSize FROM Cache WHERE bundle=? AND item=?");
+    Orthanc::SQLite::Statement s(pimpl_->db_, SQLITE_FROM_HERE, "SELECT seq, fileUuid, fileSize FROM Cache WHERE bundle=? AND item=?");
     s.BindInt(0, bundle);
     s.BindString(1, item);
     if (!s.Step())
@@ -431,11 +421,11 @@ namespace OrthancPlugins
     size = s.ColumnInt64(2);
 
     // Touch the cache to fulfill the LRU scheme.
-    SQLite::Statement t(pimpl_->db_, SQLITE_FROM_HERE, "DELETE FROM Cache WHERE seq=?");
+    Orthanc::SQLite::Statement t(pimpl_->db_, SQLITE_FROM_HERE, "DELETE FROM Cache WHERE seq=?");
     t.BindInt64(0, seq);
     if (t.Run())
     {
-      SQLite::Statement u(pimpl_->db_, SQLITE_FROM_HERE, "INSERT INTO Cache VALUES(NULL, ?, ?, ?, ?)");
+      Orthanc::SQLite::Statement u(pimpl_->db_, SQLITE_FROM_HERE, "INSERT INTO Cache VALUES(NULL, ?, ?, ?, ?)");
       u.BindInt(0, bundle);
       u.BindString(1, item);
       u.BindString(2, uuid);
@@ -475,7 +465,14 @@ namespace OrthancPlugins
     bool ok;
     try
     {
+#if defined(ORTHANC_FRAMEWORK_VERSION_IS_ABOVE) && ORTHANC_FRAMEWORK_VERSION_IS_ABOVE(1, 9, 0) 
+      std::unique_ptr<Orthanc::IMemoryBuffer> buffer(
+        pimpl_->storage_.Read(uuid, Orthanc::FileContentType_Unknown));
+      buffer->MoveToString(content);
+#else
       pimpl_->storage_.Read(content, uuid, Orthanc::FileContentType_Unknown);
+#endif
+      
       ok = (content.size() == size);
     }
     catch (std::runtime_error&)
@@ -497,15 +494,14 @@ namespace OrthancPlugins
   void CacheManager::Invalidate(int bundleIndex,
                                 const std::string& item)
   {
-    using namespace Orthanc;
     SanityCheck();
 
-    std::unique_ptr<SQLite::Transaction> transaction(new SQLite::Transaction(pimpl_->db_));
+    std::unique_ptr<Orthanc::SQLite::Transaction> transaction(new Orthanc::SQLite::Transaction(pimpl_->db_));
     transaction->Begin();
 
     Bundle bundle = GetBundle(bundleIndex);
 
-    SQLite::Statement s(pimpl_->db_, SQLITE_FROM_HERE, "SELECT seq, fileUuid, fileSize FROM Cache WHERE bundle=? AND item=?");
+    Orthanc::SQLite::Statement s(pimpl_->db_, SQLITE_FROM_HERE, "SELECT seq, fileUuid, fileSize FROM Cache WHERE bundle=? AND item=?");
     s.BindInt(0, bundleIndex);
     s.BindString(1, item);
     if (s.Step())
@@ -515,7 +511,7 @@ namespace OrthancPlugins
       uint64_t expectedSize = s.ColumnInt64(2);
       bundle.Remove(expectedSize);
 
-      SQLite::Statement t(pimpl_->db_, SQLITE_FROM_HERE, "DELETE FROM Cache WHERE seq=?");
+      Orthanc::SQLite::Statement t(pimpl_->db_, SQLITE_FROM_HERE, "DELETE FROM Cache WHERE seq=?");
       t.BindInt64(0, seq);
       if (t.Run())
       {
@@ -544,12 +540,11 @@ namespace OrthancPlugins
   void CacheManager::SetDefaultQuota(uint32_t maxCount,
                                      uint64_t maxSpace)
   {
-    using namespace Orthanc;
     SanityCheck();
 
     pimpl_->defaultQuota_ = BundleQuota(maxCount, maxSpace);
 
-    SQLite::Statement s(pimpl_->db_, SQLITE_FROM_HERE, "SELECT DISTINCT bundle FROM Cache");
+    Orthanc::SQLite::Statement s(pimpl_->db_, SQLITE_FROM_HERE, "SELECT DISTINCT bundle FROM Cache");
     while (s.Step())
     {
       EnsureQuota(s.ColumnInt(0), pimpl_->defaultQuota_);
@@ -561,16 +556,15 @@ namespace OrthancPlugins
 
   void CacheManager::Clear()
   {
-    using namespace Orthanc;
     SanityCheck();
 
-    SQLite::Statement s(pimpl_->db_, SQLITE_FROM_HERE, "SELECT fileUuid FROM Cache");
+    Orthanc::SQLite::Statement s(pimpl_->db_, SQLITE_FROM_HERE, "SELECT fileUuid FROM Cache");
     while (s.Step())
     {
       pimpl_->storage_.Remove(s.ColumnString(0), Orthanc::FileContentType_Unknown);
     }  
 
-    SQLite::Statement t(pimpl_->db_, SQLITE_FROM_HERE, "DELETE FROM Cache");
+    Orthanc::SQLite::Statement t(pimpl_->db_, SQLITE_FROM_HERE, "DELETE FROM Cache");
     t.Run();
 
     ReadBundleStatistics();
@@ -581,17 +575,16 @@ namespace OrthancPlugins
 
   void CacheManager::Clear(int bundle)
   {
-    using namespace Orthanc;
     SanityCheck();
 
-    SQLite::Statement s(pimpl_->db_, SQLITE_FROM_HERE, "SELECT fileUuid FROM Cache WHERE bundle=?");
+    Orthanc::SQLite::Statement s(pimpl_->db_, SQLITE_FROM_HERE, "SELECT fileUuid FROM Cache WHERE bundle=?");
     s.BindInt(0, bundle);
     while (s.Step())
     {
       pimpl_->storage_.Remove(s.ColumnString(0), Orthanc::FileContentType_Unknown);
     }  
 
-    SQLite::Statement t(pimpl_->db_, SQLITE_FROM_HERE, "DELETE FROM Cache WHERE bundle=?");
+    Orthanc::SQLite::Statement t(pimpl_->db_, SQLITE_FROM_HERE, "DELETE FROM Cache WHERE bundle=?");
     t.BindInt(0, bundle);
     t.Run();
 
