@@ -2,7 +2,8 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2022 Osimis S.A., Belgium
+ * Copyright (C) 2021-2022 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -31,7 +32,6 @@
 
 #include <boost/lexical_cast.hpp>
 #include <boost/algorithm/string/predicate.hpp>
-#include <json/writer.h>
 #include <boost/regex.hpp>
 
 
@@ -172,9 +172,8 @@ namespace OrthancPlugins
       {
         json["Orthanc"]["PhotometricInterpretation"] = photometric;
       }
-      
-      Json::FastWriter writer;
-      content = writer.write(json);
+
+      Orthanc::Toolbox::WriteFastJson(content, json);
       return true;
     }
     else
@@ -187,10 +186,8 @@ namespace OrthancPlugins
 
   bool DecodedImageAdapter::GetCornerstoneMetadata(Json::Value& result,
                                                    const Json::Value& tags,
-                                                   OrthancImage& image)
+                                                   const OrthancImage& image)
   {
-    using namespace Orthanc;
-
     float windowCenter, windowWidth;
 
     Orthanc::ImageAccessor accessor;
@@ -199,9 +196,9 @@ namespace OrthancPlugins
 
     switch (accessor.GetFormat())
     {
-      case PixelFormat_Grayscale8:
-      case PixelFormat_Grayscale16:
-      case PixelFormat_SignedGrayscale16:
+      case Orthanc::PixelFormat_Grayscale8:
+      case Orthanc::PixelFormat_Grayscale16:
+      case Orthanc::PixelFormat_SignedGrayscale16:
       {
         int64_t a, b;
         Orthanc::ImageProcessing::GetMinMaxIntegerValue(a, b, accessor);
@@ -223,8 +220,8 @@ namespace OrthancPlugins
         break;
       }
 
-      case PixelFormat_RGB24:
-      case PixelFormat_RGB48:
+      case Orthanc::PixelFormat_RGB24:
+      case Orthanc::PixelFormat_RGB48:
         result["minPixelValue"] = 0;
         result["maxPixelValue"] = 255;
         result["color"] = true;
@@ -310,7 +307,7 @@ namespace OrthancPlugins
 
 
   bool  DecodedImageAdapter::EncodeUsingDeflate(Json::Value& result,
-                                                OrthancImage& image)
+                                                const OrthancImage& image)
   {
     Orthanc::ImageAccessor accessor;
     accessor.AssignReadOnly(OrthancPlugins::Convert(image.GetPixelFormat()), image.GetWidth(),
@@ -424,7 +421,7 @@ namespace OrthancPlugins
 
 
   bool  DecodedImageAdapter::EncodeUsingJpeg(Json::Value& result,
-                                             OrthancImage& image,
+                                             const OrthancImage& image,
                                              uint8_t quality /* between 0 and 100 */)
   {
     Orthanc::ImageAccessor accessor;
