@@ -2,7 +2,8 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2022 Osimis S.A., Belgium
+ * Copyright (C) 2021-2022 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -24,6 +25,8 @@
 #include "../Resources/Orthanc/Plugins/OrthancPluginCppWrapper.h"
 #include "Cache/ICacheFactory.h"
 
+#include <Compatibility.h>
+
 #include <stdint.h>
 #include <json/value.h>
 
@@ -47,13 +50,13 @@ namespace OrthancPlugins
 
     static bool GetCornerstoneMetadata(Json::Value& result,
                                        const Json::Value& tags,
-                                       OrthancImage& image);
+                                       const OrthancImage& image);
 
     static bool EncodeUsingDeflate(Json::Value& result,
-                                   OrthancImage& image);
+                                   const OrthancImage& image);
 
     static bool EncodeUsingJpeg(Json::Value& result,
-                                OrthancImage& image,
+                                const OrthancImage& image,
                                 uint8_t quality /* between 0 and 100 */);
 
     OrthancPluginContext* context_;
@@ -65,6 +68,6 @@ namespace OrthancPlugins
     }
 
     virtual bool Create(std::string& content,
-                        const std::string& uri);  
+                        const std::string& uri) ORTHANC_OVERRIDE;
   };
 }
