@@ -2,7 +2,8 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2022 Osimis S.A., Belgium
+ * Copyright (C) 2021-2022 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -24,9 +25,7 @@
 #include "ViewerToolbox.h"
 #include "Cache/CacheScheduler.h"
 
-#include <json/value.h>
-#include <json/reader.h>
-
+#include <Toolbox.h>
 
 
 static const Json::Value::ArrayIndex PREFETCH_FORWARD = 10;
@@ -41,8 +40,7 @@ namespace OrthancPlugins
                                          const std::string& content)
   {
     Json::Value json;
-    Json::Reader reader;
-    if (!reader.parse(content, json) ||
+    if (!Orthanc::Toolbox::ReadJson(json, content) ||
         !json.isMember("Slices"))
     {
       return;
@@ -93,8 +91,7 @@ namespace OrthancPlugins
     }
     
     Json::Value series;
-    Json::Reader reader;
-    if (!reader.parse(tmp, series) ||
+    if (!Orthanc::Toolbox::ReadJson(series, tmp) ||
         !series.isMember("Slices"))
     {
       return;
