@@ -2,7 +2,8 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2022 Osimis S.A., Belgium
+ * Copyright (C) 2021-2022 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -28,7 +29,6 @@
 // To gain access to ORTHANC_PLUGINS_VERSION_IS_ABOVE if Orthanc SDK <= 1.3.0
 #include "../Resources/Orthanc/Plugins/OrthancPluginCppWrapper.h"
 
-#include <json/reader.h>
 #include <stdexcept>
 #include <boost/lexical_cast.hpp>
 #include <sys/stat.h>
@@ -79,10 +79,7 @@ namespace OrthancPlugins
     {
       try
       {
-        const char* data = reinterpret_cast<const char*>(answer.data);
-        Json::Reader reader;
-        if (!reader.parse(data, data + answer.size, json, 
-                          false /* don't collect comments */))
+        if (!Orthanc::Toolbox::ReadJsonWithoutComments(json, answer.data, answer.size))
         {
           return false;
         }
@@ -227,8 +224,7 @@ namespace OrthancPlugins
       OrthancPluginFreeString(context, tmp);      
     }
 
-    Json::Reader reader;
-    if (reader.parse(s, configuration))
+    if (Orthanc::Toolbox::ReadJson(configuration, s))
     {
       return true;
     }
