@@ -2,7 +2,8 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2022 Osimis S.A., Belgium
+ * Copyright (C) 2021-2022 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -424,10 +425,18 @@ $(document).ready(function() {
     success: function(volume) {
       if (volume.Slices.length != 0) {
         instances = volume.Slices;
-        $('#topright').html(volume.PatientID + '<br/>' +
-                            volume.PatientName + '<br/>' +
-                            volume.StudyDescription + '<br/>' +
-                            volume.SeriesDescription + '<br/>');
+        var topRightElement = $('<span>');
+        topRightElement.append($('<span>', { text: volume.PatientID}));
+        topRightElement.append($('<br/>'));
+        topRightElement.append($('<span>', { text: volume.PatientName}));
+        topRightElement.append($('<br/>'));
+        topRightElement.append($('<span>', { text: volume.StudyDescription}));
+        topRightElement.append($('<br/>'));
+        topRightElement.append($('<span>', { text: volume.SeriesDescription}));
+        topRightElement.append($('<br/>'));
+
+        $('#topright').empty();
+        $('#topright').append(topRightElement);
       }
     },
     failure: function() {
